@@ -1,5 +1,5 @@
 package List::Compare;
-$VERSION = 0.12;   # 7/20/02
+$VERSION = 0.13;   # August 3, 2002
 
 use strict;
 use warnings;
@@ -884,8 +884,8 @@ List::Compare - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.12 of List::Compare.  This version was
-released July 20, 2002.
+This document refers to version 0.13 of List::Compare.  This version was
+released August 3, 2002.
 
 =head1 SYNOPSIS
 
@@ -1402,7 +1402,7 @@ you must first install the Want module, also available on CPAN.
 
 James E. Keenan (jkeen@concentric.net).
 
-Creation date:  May 20, 2002.  Last modification date:  July 20, 2002. 
+Creation date:  May 20, 2002.  Last modification date:  August 3, 2002. 
 Copyright (c) 2002 James E. Keenan.  United States.  All rights reserved. 
 This is free software and may be distributed under the same terms as Perl
 itself.
